… | OiRA

Help

1. Preparation
2. Involve
3. Identification + Evaluation
   1. 1 Commercial manned guarding
   2. Ω Other risks
      1. Ω.1 The entrance floor is often wet
      2. Ω.2 …
   - Unanswered
   - Postponed
   - No risk
   - Risk identified
4. Action Plan
5. Report
6. Status 0%

## Describe the risk…

Is this risk acceptable or under control? If applicable, add all measures that have already been implemented. No, more measures are required Yes, the remaining risk is acceptable

Select the priority of this risk Low Medium High
Information
Upload imagelabel_upload_image
Comments

Scroll to top
Back

## add-risk.html

More…

- New risk assessment
- Show archived risk assessments
- All types of risk assessments Only regular risk assessments Only contractor risk assessments

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More